Apply an inclusion radius and exclusion buffer to indices
Usage
buffer_indices(data, indices, radius, buffer, call = rlang::caller_env())Arguments
- data
An object of class
sforsfc.- indices
List of indices in each fold generated by
split_unnamed().- radius
Numeric: points within this distance of the initially-selected test points will be assigned to the assessment set. If
NULL, no radius is applied.- buffer
Numeric: points within this distance of any point in the test set (after
radiusis applied) will be assigned to neither the analysis or assessment set. IfNULL, no buffer is applied.